package com.muyu.shop.cart.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.shop.cart.domain.CartInfo;
import com.muyu.shop.cart.domain.req.CartInfoQueryReq;
import com.muyu.shop.cart.domain.req.CartInfoSaveReq;
import com.muyu.shop.cart.domain.req.CartInfoEditReq;
import com.muyu.shop.cart.service.CartInfoService;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 购物车Controller
 *
 * @author DongZeLiang
 * @date 2024-03-29
 */
@Api(tags = "购物车")
@RestController
@RequestMapping("/Info")
public class CartInfoController extends BaseController {
    @Autowired
    private CartInfoService cartInfoService;

    /**
     * 查询购物车列表
     */
    @ApiOperation("获取购物车列表")
    @RequiresPermissions("shopCart:Info:list")
    @GetMapping("/list")
    public Result<TableDataInfo<CartInfo>> list(CartInfoQueryReq cartInfoQueryReq) {
        startPage();
        List<CartInfo> list = cartInfoService.list(CartInfo.queryBuild(cartInfoQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出购物车列表
     */
    @ApiOperation("导出购物车列表")
    @RequiresPermissions("shopCart:Info:export")
    @Log(title = "购物车", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CartInfo cartInfo) {
        List<CartInfo> list = cartInfoService.list(cartInfo);
        ExcelUtil<CartInfo> util = new ExcelUtil<CartInfo>(CartInfo.class);
        util.exportExcel(response, list, "购物车数据");
    }

    /**
     * 获取购物车详细信息
     */
    @ApiOperation("获取购物车详细信息")
    @RequiresPermissions("shopCart:Info:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<CartInfo> getInfo(@PathVariable("id") Long id) {
        return Result.success(cartInfoService.getById(id));
    }

    /**
     * 新增购物车
     */
    @RequiresPermissions("shopCart:Info:add")
    @Log(title = "购物车", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增购物车")
    public Result<String> add(@RequestBody CartInfoSaveReq cartInfoSaveReq) {
        return toAjax(cartInfoService.save(CartInfo.saveBuild(cartInfoSaveReq)));
    }

    /**
     * 修改购物车
     */
    @RequiresPermissions("shopCart:Info:edit")
    @Log(title = "购物车", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改购物车")
    public Result<String> edit(@PathVariable Long id, @RequestBody CartInfoEditReq cartInfoEditReq) {
        return toAjax(cartInfoService.updateById(CartInfo.editBuild(id,cartInfoEditReq)));
    }

    /**
     * 删除购物车
     */
    @RequiresPermissions("shopCart:Info:remove")
    @Log(title = "购物车", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除购物车")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(cartInfoService.removeBatchByIds(ids));
    }
}
